require 'ostruct'
require 'minitest/autorun'
require 'fileutils'
require 'roopap/organizer'

module Roopap
  describe "Organizer" do
    let(:output_dir) { 'tmp/out' }

    before do
      FileUtils.mkdir_p(output_dir)
    end

    after do
      FileUtils.rm_r(output_dir)
    end

    it "copies all images under SOURCE directory to month directories under DEST directory
          according to the image created date" do
      source = 'spec/fixtures/1'
      target = output_dir

      Organizer.new.perform(source, target)

      assert FileTest.exists?("#{target}/2006-01/e489272393.jpg"), "No file in the target directory"
      assert FileTest.exists?("#{target}/2011-04/bb455c47e4.jpg"), "No file in the target directory"
    end

    it "ignores non jpg file" do
      source = 'spec/fixtures/2'
      target = output_dir

      Organizer.new.perform(source, target)

      assert FileTest.exists?("#{target}/2006-01/e489272393.jpg"), "No file in the target directory"
    end

    it "returns number of organized files" do
      source = 'spec/fixtures/1'
      target = output_dir

      o = Organizer.new
      o.perform(source, target)
      out = o.organized_file_count

      assert_equal out, 2, "Number of organized files"
    end

    it "works with date_time in String format" do
      source = 'spec/fixtures/1'
      target = output_dir
      o = Organizer.new

      EXIFR::JPEG.stub :new, OpenStruct.new(date_time_original: '16 Feb 2011 20:35:30') do
        o.perform(source, target)
      end

      assert FileTest.exists?("#{target}/2011-02/e489272393.jpg"), "No file in the target directory"
    end
  end
end
